@@ -144,6 +144,8 @@
 ( cd opt/kde/share/doc/HTML/fr/konquest ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kspaceduel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kverbos ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kverbos ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kweather ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kwuftpd ; rm -rf common )
@@ -154,6 +156,8 @@
 ( cd opt/kde/share/doc/HTML/fr/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kioslave ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/flashkard ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/flashkard ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kbackgammon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/aktion ; rm -rf common )
@@ -396,6 +400,8 @@
 ( cd opt/kde/share/doc/HTML/fr/kasteroids ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/keduca ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/keduca ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kmessedwords ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kicker ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/klines ; rm -rf common )
